@@ -26,10 +26,24 @@
 
 #include <stdlib.h>
 
+#undef __BEGIN_DECLS
+#undef __END_DECLS
+#ifdef __cplusplus
+# define __BEGIN_DECLS extern "C" {
+# define __END_DECLS }
+#else
+# define __BEGIN_DECLS /* empty */
+# define __END_DECLS /* empty */
+#endif
+
+__BEGIN_DECLS
+
 #define Calloc(n,t)    (t*) calloc( (size_t)(n), sizeof(t) )
 #define Realloc(p,n,t) (t*) realloc((void*)(p), (size_t)((n)*sizeof(t)))
 #define Free(p)        (free( (void *)(p) ), (p) = NULL)
 
 int igraph_free(void *p);
 
+__END_DECLS
+
 #endif
